@@ -13,7 +13,7 @@ our @EXPORT_OK   = qw(
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 my $timescale;
 my $endtime;
@@ -306,7 +306,7 @@ Verilog::VCD - Parse a Verilog VCD text file
 
 =head1 VERSION
 
-This document refers to Verilog::VCD version 0.06.
+This document refers to Verilog::VCD version 0.07.
 
 =head1 SYNOPSIS
 
@@ -540,7 +540,7 @@ An example returned structure is:
 =head2 get_dumps( )
 
 This returns a hash-of-arrays corresponding to the C<$dump*> VCD keywords
-(C<$dumpvars>, C<$dumpon>, etc.).  in the declaration section of the VCD
+(C<$dumpvars>, C<$dumpon>, etc.) in the simulation section of the VCD
 file.  The keys of the hash are the keywords, and the values are the
 simulation times at which the keywords occurred.  It returns the dump
 commands for the last VCD file parsed.  If called before a file is parsed,
